@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: command.c,v 1.292.2.13 2016/08/19 16:14:08 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: command.c,v 1.292.2.15 2017/03/02 18:24:52 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - command.c */
@@ -1342,7 +1342,7 @@ clause_reset_after_error()
 void
 timed_pause(double sleep_time)
 {
-#if defined(HAVE_USLEEP) && defined(USE_MOUSE)
+#if defined(HAVE_USLEEP) && defined(USE_MOUSE) && !defined(_WIN32)
     if (term->waitforinput)		/* If the terminal supports it */
 	while (sleep_time > 0.05) {	/* we poll 20 times a second */
 	    usleep(50000);		/* Sleep for 50 msec */
@@ -1586,6 +1586,9 @@ plot_command()
     add_udv_by_name("MOUSE_CTRL")->udv_undef = TRUE;
 #endif
     plotrequest();
+    /* Clear "hidden" flag for any plots that may have been toggled off */
+    if (term->modify_plots)
+	term->modify_plots(MODPLOTS_SET_VISIBLE, -1);
     SET_CURSOR_ARROW;
 }
 
@@ -1976,6 +1979,9 @@ splot_command()
     add_udv_by_name("MOUSE_BUTTON")->udv_undef = TRUE;
 #endif
     plot3drequest();
+    /* Clear "hidden" flag for any plots that may have been toggled off */
+    if (term->modify_plots)
+	term->modify_plots(MODPLOTS_SET_VISIBLE, -1);
     SET_CURSOR_ARROW;
 }
 
